#
# spec file for package apache2-mod_auth_gssapi
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2004, 2005 NOVELL (All rights reserved)
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# kinit: Configuration file does not specify default realm when parsing name maguser
%define test 0
Name:           apache2-mod_auth_gssapi
Version:        1.6.5
Release:        3.1
Summary:        GSSAPI Module for Apache
License:        MIT
URL:            https://github.com/gssapi/mod_auth_gssapi/
Source0:        https://github.com/gssapi/mod_auth_gssapi/releases/download/v%{version}/mod_auth_gssapi-%{version}.tar.gz
# python3 and other testsuite fixes
Patch0:         apache2-mod_auth_gssapi-test.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  byacc
BuildRequires:  flex
BuildRequires:  krb5-devel
BuildRequires:  openssl-devel
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2
# SECTION test requirements
%if %{test} == 1
BuildRequires:  krb5-client
BuildRequires:  krb5-plugin-preauth-pkinit
BuildRequires:  krb5-server
BuildRequires:  nss_wrapper
BuildRequires:  python3-gssapi
BuildRequires:  python3-requests-gssapi
BuildRequires:  python3-requests-kerberos
BuildRequires:  socket_wrapper
%endif
# /SECTION

%description
This module has been built as a replacement for the aging
mod_auth_kerb. Its aim is to use only GSSAPI calls and be
as much as possible agnostic of the actual mechanism used.

%prep
%autosetup -p1 -n mod_auth_gssapi-%{version}

%build
export APACHE="%{_sbindir}/httpd"
%configure
%make_build APXS=%{apache_apxs}

%install
%make_install
rm %{buildroot}%{apache_libexecdir}/*.la

%check
%if %{test} == 1
sed -i 's/env python3/python3/' tests/*.py
export PATH="$PATH:%{_sbindir}"
make check
%endif

%files
%license COPYING
%doc README
%{apache_libexecdir}/*.so

%changelog
* Thu Apr  3 2025 pgajdos@suse.com
- turn the testsuite off even for Factory for now, it appears it
  requires certain kerberos tweaks
  [kinit: Configuration file does not specify default realm when parsing name maguser]
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Jul 17 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 1.6.5:
  * Fix a bad crash bug when the GssapiUseS4U2Proxy option is set
    but no GssapiCredStore directives are provided at all.
  - crash bug when s4u2proxy is configured by @simo5 in #272
- rebased patch apache2-mod_auth_gssapi-test.patch
* Mon Jul 17 2023 Johannes Kastl <kastl@b1-systems.de>
- change upstream URL to https://github.com/gssapi/mod_auth_gssapi,
  because https://github.com/modauthgssapi/mod_auth_gssapi has no
  releases, no activity and looks fishy
- upgrade to 1.6.4:
  * tests: Catch errors during tests setup by @stanislavlevin in
    [#225]
  * tests: Don't override the specific environment by the global
    one by @stanislavlevin in #227
  * Emit error in logs if keytab files can't be opened by @simo5 in
    [#229]
  * Add warnings if s4u2proxy options are inconsistent by @simo5 in
    [#232]
  * Move to python3 by default by @frozencemetery in #235
  * Fix type/token distinction in parser.y by @frozencemetery in
    [#237]
  * Special ccache handling for {HOSTNAME} acceptor by @simo5 in
    [#238]
  * crypto: Handle EVP changes in OpenSSL 3 by @frozencemetery in
    [#256]
* Thu Feb  3 2022 pgajdos@suse.com
- test only when test requirements are fulfilled
* Wed Nov 25 2020 pgajdos@suse.com
- version update to 1.6.3
  * add a few options to expose the mechanism used for authentication
    (when multiple are available) and to control the timeout interval
    for Basic Auth sessions
  * CI and other minor fixes, as well as a fix for gss_localname()
  * see
    https://github.com/gssapi/mod_auth_gssapi/releases
- modified patches
  %% apache2-mod_auth_gssapi-test.patch (refreshed)
* Wed Apr  8 2020 pgajdos@suse.com
- version update to 1.6.1
  * lot of changes, see
    https://github.com/gssapi/mod_auth_gssapi/releases
- added patches
  python3 and other testsuite fixes
  + apache2-mod_auth_gssapi-test.patch
* Sun Feb  9 2020 pgajdos@suse.com
- removing %%apache_test_* macros, do not test module just by
  loading the module
* Tue Feb 28 2017 k0da@opensuse.org
- Initial mod_gssapi-1.5 version
